SystemOrganization addCategory: #'Math-Tests-ODE'!

TestCase subclass: #AB2StepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!AB2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/10/2013 12:05'!
testOrderIsTwo
	self should: [AB2Stepper order = 2]
! !

!AB2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:42'!
testSimpleSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | t sin].
	stepper := AB2Stepper onSystem: system.
	solver := (AB2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: -1 startTime: 0 endTime: Float pi) closeTo: 1].
	! !

!AB2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/21/2013 14:03'!
testSimpleSystem2
	| solver stepper system dt |
	dt := 1.5.
	system := ExplicitSystem block: [:x :t | 3 * (t negated exp) - (0.4 * x)].
	stepper := AB2Stepper onSystem: system.
	solver := (AB2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 5 startTime: 0 endTime: 1.5) closeTo: 3.6756494873345655].
	self should: ((solver solve: system startState: 5 startTime: 0 endTime: 3) closeTo:  1.1236935297353574).! !

!AB2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 18:29'!
testSimpleSystem3
	| solver stepper system dt |
	dt := 0.5.
	system := ExplicitSystem block: [:x :t | 2 * t * x].
	stepper := AB2Stepper onSystem: system.
	solver := (AB2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 0.5) closeTo: 1.25].
	self should: [(solver solve: system startState: 1.25 startTime: 0.5 endTime: 1) closeTo: 2.421875].
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 1) closeTo: 2.1875].! !

!AB2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/23/2013 15:20'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := AB2Stepper onSystem: system.
	solver := (AB2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [((   solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((   solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !

TestCase subclass: #BDF2SolverTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!BDF2SolverTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/10/2013 15:51'!
testSolveStartStateStartTimeEndTimeStepSize
	| solver stepper system dt finalState |
	dt := 0.2.
	system := ImplicitSystem block: [:x :t | (t * x ) exp].
	stepper := ImplicitStepper onSystem: system.
	stepper stepSize: dt.
	solver := (BDF2Solver new 
				system: system; 
				stepper: stepper).
	finalState := solver solve: solver system startState: 0 startTime: 0  endTime: 1 stepSize: dt. 
	self should: [finalState isFloat].
	
	"Debgging information"
	Transcript 
		show: self class name asByteString;  cr; 
		show: system block asText ; cr;
		show: 'from x(0) = 0 to x(1) = ';
		show: finalState; cr;
		show: 'with stepSize = ', solver dt printString; cr.! !

!BDF2SolverTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/10/2013 15:49'!
testSolveX0T0T1
	| solver stepper system dt finalState |
	dt := 0.1.
	system := ImplicitSystem block: [:x :t | (t * x ) exp].
	stepper := ImplicitStepper onSystem: system.
	stepper stepSize: dt.
	solver := (BDF2Solver new 
				system: system; 
				stepper: stepper;
				dt: dt).
	finalState := solver solve: solver system startState: 0 startTime: 0  endTime: 1. 
	self should: [finalState isFloat].
	
	"Debgging information"
	Transcript 
		show: self class name asByteString;  cr; 
		show: system block asText ; cr;
		show: 'from x(0) = 0 to x(1) = ';
		show: finalState; cr;
		show: 'with stepSize = ', solver dt printString; cr.! !

TestCase subclass: #BDF2StepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!BDF2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/10/2013 12:06'!
testOrderIsTwo
	self should: [BDF2Stepper order = 2]! !

!BDF2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:43'!
testSimpleSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ImplicitSystem block: [:x :t | t sin].
	stepper := BDF2Stepper onSystem: system.
	solver := (BDF2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: -1 startTime: 0 endTime: Float pi) closeTo: 1].! !

!BDF2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/21/2013 15:58'!
testSimpleSystem2
	| solver stepper system dt |
	dt := 1.5.
	system := ImplicitSystem block: [:x :t | 3 * (t negated exp) - (0.4 * x)].
	stepper := BDF2Stepper onSystem: system.
	solver := (BDF2Solver new) stepper: stepper; system: system; dt: dt.
	self should: ((solver solve: system startState: 5 startTime: 0 endTime: 3) closeTo:  2.393822315308974).
	self should: [(solver solve: system startState: 5 startTime: 0 endTime: 1.5) closeTo: 3.6756494873345655].
	! !

!BDF2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/21/2013 16:06'!
testSimpleSystem3
	| solver stepper system dt |
	dt := 0.5.
	system := ImplicitSystem block: [:x :t | 2 * t * x].
	stepper := BDF2Stepper onSystem: system.
	solver := (BDF2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 0.5) closeTo: 1.25].
	self should: [(solver solve: system startState: 1.25 startTime: 0.5 endTime: 1) closeTo: 2.421875].
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 1) closeTo: 2.583333333333333].! !

!BDF2StepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:44'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ImplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := BDF2Stepper onSystem: system.
	solver := (BDF2Solver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !

TestCase subclass: #ExplicitSolverTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!ExplicitSolverTest commentStamp: '<historical>' prior: 0!
An ODESolverTest is a test class for testing the behavior of ODESolver!

!ExplicitSolverTest methodsFor: 'tests-solving' stamp: 'NataliaMoskovchuk 7/15/2013 15:47'!
testSolveStartStateStartTimeEndTimeStepSize
	| solver stepper system dt finalState |
	dt := 0.2.
	system := ExplicitSystem block: [:x :t | (t * x ) exp].
	stepper := ExplicitStepper onSystem: system.
	stepper stepSize: dt.
	solver := (ExplicitSolver new 
				system: system; 
				stepper: stepper).
	finalState := solver solve: solver system startState: 0 startTime: 0  endTime: 1 stepSize: dt. 
	self should: [finalState isFloat].
	
	"Debgging information"
	Transcript 
		show: self class name asByteString;  cr; 
		show: system block asText ; cr;
		show: 'from x(0) = 0 to x(1) = ';
		show: finalState; cr;
		show: 'with stepSize = ', solver dt printString; cr.! !

!ExplicitSolverTest methodsFor: 'tests-solving' stamp: 'NataliaMoskovchuk 7/15/2013 15:48'!
testSolveX0T0T1
	| solver stepper system dt finalState |
	dt := 0.1.
	system := ExplicitSystem block: [:x :t | (t * x ) exp].
	stepper := ExplicitStepper onSystem: system.
	stepper stepSize: dt.
	solver := (ExplicitSolver new 
				system: system; 
				stepper: stepper;
				dt: dt).
	finalState := solver solve: solver system startState: 0 startTime: 0  endTime: 1. 
	self should: [finalState isFloat].
	
	"Debgging information"
	Transcript 
		show: self class name asByteString;  cr; 
		show: system block asText ; cr;
		show: 'from x(0) = 0 to x(1) = ';
		show: finalState; cr;
		show: 'with stepSize = ', solver dt printString; cr.! !

TestCase subclass: #ExplicitStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!ExplicitStepperTest commentStamp: '<historical>' prior: 0!
An ExplicitStepperTest is a test class for testing the behavior of ExplicitStepper!

!ExplicitStepperTest methodsFor: 'tests-stepping' stamp: 'NataliaMoskovchuk 7/23/2013 20:48'!
testDoStepTime
	"this is identical to testDoStepTimeStepSize except dt is stored."
	| stepper sys dt |
	sys := ExplicitSystem block: [:x :t | x * t].
	stepper := ExplicitStepper onSystem: sys.
	dt := 0.1.
	stepper stepSize: dt.
	self should: [stepper stepSize = dt].
	self should: [(stepper doStep: 0 time: 10) = 0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: 1) = 10 ].

	"stepSize parameter changes the stored stepSize"
	self should: [(stepper stepSize = 1)].

	self should: [(stepper doStep: 1 time:  1) = 2].
	self should: [(stepper doStep: 10 time:  1 stepSize: 0.2) = 12.0].! !

!ExplicitStepperTest methodsFor: 'tests-stepping' stamp: 'DanielUber 5/22/2012 10:59'!
testDoStepTimeStepSize
	| stepper sys dt |
	sys := ExplicitSystem block: [:x :t | x * t].
	stepper := ExplicitStepper onSystem: sys.
	dt := 0.1.
	self should: [(stepper doStep: 0 time: 10 stepSize: dt) = 0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: dt) = 10 ].
	self should: [(stepper doStep: 1 time:  1 stepSize: dt) = 1.1].
	self should: [(stepper doStep: 10 time:  1 stepSize: dt) = 11.0].! !

!ExplicitStepperTest methodsFor: 'tests-stepping' stamp: 'DanielUber 5/22/2012 11:02'!
testOrderOfBaseExplicitStepperIsOne
	| order |
	order := ExplicitStepper new order.
	self should: [order notNil].
	self should: [order = 1].! !

!ExplicitStepperTest methodsFor: 'tests-stepping' stamp: 'NataliaMoskovchuk 7/23/2013 20:50'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := ExplicitStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1.0049].! !

TestCase subclass: #ImplMidpointStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!ImplMidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/12/2013 08:44'!
testOrderIsTwo
	self should: [ImplMidpointStepper order = 2]! !

!ImplMidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/23/2013 12:55'!
testSimpleSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ImplicitSystem block: [:x :t | t sin].
	stepper := ImplMidpointStepper onSystem: system.
	solver := (ImplMidpointSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: -1 startTime: 0 endTime: Float pi) closeTo: 1].! !

!ImplMidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/23/2013 21:31'!
testSimpleSystem3
	<expectedFailure>
	| solver stepper system dt |
	dt := 0.01.
	system := ImplicitSystem block: [:x :t | 2 * t * x].
	stepper := ImplMidpointStepper onSystem: system.
	solver := (ImplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 1) closeTo: 2.634765625].! !

!ImplMidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/23/2013 21:30'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ImplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := ImplMidpointStepper onSystem: system.
	solver := (ImplMidpointSolver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !

TestCase subclass: #ImplicitStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!ImplicitStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:09'!
testDoStepTime
	"this is identical to testDoStepTimeStepSize except dt is stored."
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | x * t].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	stepper stepSize: dt.
	self should: [stepper stepSize = dt].
	self should: [(stepper doStep: 0 time: 10) = 0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: 1) = 10 ].

	"stepSize parameter changes the stored stepSize"
	self should: [(stepper stepSize = 1)].

	self should: [(stepper doStep: 1 time:  1) = 2].
	self should: [(stepper doStep: 10 time:  1 stepSize: 0.2) = 12.0].! !

!ImplicitStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/3/2013 23:22'!
testDoStepTimeStepSize
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | x * t].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	self should: [(stepper doStep: 0 time: 10 stepSize: dt) = 0.0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: dt) = 10.0 ].
	self should: [(stepper doStep: 1 time:  1 stepSize: dt) = 1.1].
	self should: [(stepper doStep: 10 time:  1 stepSize: dt) = 11.0].! !

TestCase subclass: #MidpointStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!MidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 4/21/2013 16:26'!
testOrderIsTwo
	self should: [MidpointStepper order = 2]! !

!MidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:47'!
testSimpleSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | t sin].
	stepper := MidpointStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: -1 startTime: 0 endTime: Float pi) closeTo: 1].! !

!MidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/21/2013 13:47'!
testSimpleSystem2
	| solver stepper system dt |
	dt := 1.5.
	system := ExplicitSystem block: [:x :t | 3 * (t negated exp) - (0.4 * x)].
	stepper := MidpointStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 5 startTime: 0 endTime: 1.5) closeTo: 3.6756494873345655].
	self should: [(solver solve: system startState: 5 startTime: 0 endTime: 3) closeTo: 2.3049].
	! !

!MidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:46'!
testSimpleSystem3
	| solver stepper system dt |
	dt := 0.5.
	system := ExplicitSystem block: [:x :t | 2 * t * x].
	stepper := MidpointStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 0.5) closeTo: 1.25].
	self should: [(solver solve: system startState: 1 startTime: 0 endTime: 1) closeTo: 2.421875].! !

!MidpointStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:46'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := MidpointStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !

TestCase subclass: #ODESystemTest
	instanceVariableNames: 'sys'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!ODESystemTest commentStamp: '<historical>' prior: 0!
An ODESystemTest is a test class for testing the behavior of ODESystem!

!ODESystemTest methodsFor: 'running' stamp: 'NataliaMoskovchuk 7/3/2013 23:29'!
setUp
	"create a dummy system"
	sys := ODESystem new.! !

!ODESystemTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 10:15'!
testBlock
	| aBlock |
	aBlock := [:x : t | t].
	sys block: aBlock.
	self should: [sys block = aBlock].! !

!ODESystemTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 11:29'!
testVectorBlock
	"this illustrates using a block that operates on a collection"
	| aBlock |
	aBlock := [:x : t | x collect: [:ea | t]].
	sys block: aBlock.
	self should: [sys block = aBlock].! !

!ODESystemTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 11:28'!
testVectorXT
	"a simple example of using a collection as state"
	| aBlock |
	aBlock := [:x : t | x collect: [:ea | t]].
	sys block: aBlock.
	self should: [(sys x: #(1 2 3) t: 2 ) = #(2 2 2)].
	self should: [(sys x: #(0 0) t: 2) = #(2 2)].
! !

!ODESystemTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 10:16'!
testXT
	| aBlock |
	aBlock := [:x : t | t].
	sys block: aBlock.
	self should: [(sys x: 1 t: 2 ) = 2].
	self should: [(sys x: 0 t: 2) = 2].
! !

TestCase subclass: #RungeKuttaStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!RungeKuttaStepperTest methodsFor: 'as yet unclassified' stamp: 'DanielUber 6/4/2012 09:15'!
testOrderIsFour
	self should: [RungeKuttaStepper order = 4].! !

!RungeKuttaStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:49'!
testSimpleSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | t sin].
	stepper := RungeKuttaStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [(solver solve: system startState: -1 startTime: 0 endTime: Float pi) closeTo: 1].
	! !

!RungeKuttaStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/15/2013 15:50'!
testVectorSystem
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := RungeKuttaStepper onSystem: system.
	solver := (ExplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !

TestCase subclass: #StepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!StepperTest commentStamp: '<historical>' prior: 0!
A StepperTest is a test class for testing the behavior of Stepper!

!StepperTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 10:26'!
testOrderIsNilForBaseClass
	self should: [Stepper order isNil].! !

!StepperTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 10:27'!
testOrderIsNilForInstanceOfBaseClass
	self should: [Stepper new order isNil].! !

!StepperTest methodsFor: 'tests' stamp: 'DanielUber 5/22/2012 10:42'!
testSystem
	| stepper sys |
	sys := ExplicitSystem new.
	sys block: [: x :t | t].
	stepper := Stepper onSystem: sys.
	self should: [stepper system = sys].
	sys := ExplicitSystem new.
	self shouldnt: [stepper system = sys].
	! !

TestCase subclass: #TrapezoidStepperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Math-Tests-ODE'!

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:07'!
testDoStepTime
	"this is identical to testDoStepTimeStepSize except dt is stored."
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | x * t].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	stepper stepSize: dt.
	self should: [stepper stepSize = dt].
	self should: [(stepper doStep: 0 time: 10) = 0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: 1) = 10 ].

	"stepSize parameter changes the stored stepSize"
	self should: [(stepper stepSize = 1)].

	self should: [(stepper doStep: 1 time:  1) = 2].
	self should: [(stepper doStep: 10 time:  1 stepSize: 0.2) = 12.0].! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:08'!
testDoStepTime1
	"this is identical to testDoStepTimeStepSize except dt is stored."
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | 3 * t negated exp - (0.4 * x)].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	stepper stepSize: dt.
	self should: [stepper stepSize = dt].
	self should: [(stepper doStep: 0 time: 10) = 1.3619978928745448e-5 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: 1) = 9.0 ].

	"stepSize parameter changes the stored stepSize"

	self should: [(stepper doStep: 5 time:  0 stepSize: 1.5) = 6.5].! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:08'!
testDoStepTimeStepSize
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t |  t sin].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	self should: [(stepper doStep: 0 time: 10 stepSize: dt) = -0.05440211108893698 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: dt) = 10.0 ].
	self should: [(stepper doStep: 1 time:  1 stepSize: dt) =1.0841470984807897].
	self should: [(stepper doStep: 10 time:  1 stepSize: dt) = 10.08414709848079].! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:08'!
testDoStepTimeStepSize1
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | x * t].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	self should: [(stepper doStep: 0 time: 10 stepSize: dt) = 0.0 ].
	self should: [(stepper doStep: 10 time: 0 stepSize: dt) = 10.0 ].
	self should: [(stepper doStep: 1 time:  1 stepSize: dt) = 1.1].
	self should: [(stepper doStep: 10 time:  1 stepSize: dt) = 11.0].! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:09'!
testDoStepTimeStepSize2
	| stepper sys dt |
	sys := ImplicitSystem block: [:x :t | 3 * t negated exp - (0.4 * x)].
	stepper := ImplicitStepper onSystem: sys.
	dt := 0.1.
	self should: [(stepper doStep: 1 time:  1 stepSize: dt) = 1.0703638323514326].
	self should: [(stepper doStep: 10 time:  1 stepSize: dt) = 9.710363832351433].! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/9/2013 00:09'!
testOrderIsTwo
	self should: [TrapezoidStepper order = 2]! !

!TrapezoidStepperTest methodsFor: 'as yet unclassified' stamp: 'NataliaMoskovchuk 7/23/2013 21:24'!
testVectorSystem
	<expectedFailure>
	| solver stepper system dt |
	dt := 0.01.
	system := ExplicitSystem block: [:x :t | | c | c:= DhbVector new: 2. 
												c at: 1 put: t sin. 
												c at: 2 put: t cos.
												c].
	stepper := TrapezoidStepper onSystem: system.
	solver := (ImplicitSolver new) stepper: stepper; system: system; dt: dt.
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi ) at: 1)closeTo: 1].
	self should: [((solver solve: system startState: #(-1 0) startTime: 0 endTime: Float pi / 2 ) at: 2 ) closeTo: 1].! !
